# Generated by Django 2.2.24 on 2024-02-18 17:26

import datetime
from django.conf import settings
import django.contrib.postgres.fields.jsonb
import django.contrib.postgres.search
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import ishtar_common.models
import ishtar_common.models_common
import re


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('ishtar_common', '0235_default_geo_types'),
    ]

    operations = [
        migrations.CreateModel(
            name='ShootingAngle',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('label', models.TextField(verbose_name='Label')),
                ('txt_idx', models.TextField(help_text='The slug is the standardized version of the name. It contains only lowercase letters, numbers and hyphens. Each slug must be unique.', unique=True, validators=[django.core.validators.RegexValidator(re.compile('^[-a-zA-Z0-9_]+\\Z'), "Enter a valid 'slug' consisting of letters, numbers, underscores or hyphens.", 'invalid')], verbose_name='Textual ID')),
                ('comment', models.TextField(blank=True, default='', verbose_name='Comment')),
                ('available', models.BooleanField(default=True, verbose_name='Available')),
                ('order', models.IntegerField(default=10, verbose_name='Order')),
            ],
            options={
                'verbose_name': 'Shooting angle',
                'verbose_name_plural': 'Shooting angles',
                'ordering': ('order', 'label'),
            },
            bases=(ishtar_common.models_common.Cached, models.Model),
        ),
        migrations.AlterModelOptions(
            name='licensetype',
            options={'ordering': ('parent__label', 'order', 'label'), 'verbose_name': 'License type', 'verbose_name_plural': 'License types'},
        ),
        migrations.AddField(
            model_name='document',
            name='copyright',
            field=models.TextField(blank=True, default='', verbose_name='Copyright'),
        ),
        migrations.AddField(
            model_name='document',
            name='rights_owner',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='ishtar_common.Organization', verbose_name='Rights owner'),
        ),
        migrations.AddField(
            model_name='historicaldocument',
            name='copyright',
            field=models.TextField(blank=True, default='', verbose_name='Copyright'),
        ),
        migrations.AddField(
            model_name='historicaldocument',
            name='rights_owner',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='ishtar_common.Organization', verbose_name='Rights owner'),
        ),
        migrations.AddField(
            model_name='historicalorganization',
            name='museum_museofile_id',
            field=models.TextField(blank=True, default='', verbose_name='Museofile id'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='museum',
            field=models.BooleanField(default=False, help_text='Need finds module', verbose_name='Museum module'),
        ),
        migrations.AddField(
            model_name='ishtarsiteprofile',
            name='museum_complete_identifier',
            field=models.TextField(default='{% if museum_id_prefix %}{{museum_id_prefix}}.{% endif %}{{museum_id}}{% if museum_id_suffix %}.{{museum_id_suffix}}{% endif %}', help_text='Formula to manage cached label. If not set a default formula is used.', verbose_name='Find - Complete museum ID'),
        ),
        migrations.AddField(
            model_name='licensetype',
            name='order',
            field=models.IntegerField(default=10, verbose_name='Order'),
        ),
        migrations.AddField(
            model_name='licensetype',
            name='parent',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='ishtar_common.LicenseType', verbose_name='Parent'),
        ),
        migrations.AddField(
            model_name='organization',
            name='museum_museofile_id',
            field=models.TextField(blank=True, default='', verbose_name='Museofile id'),
        ),
        migrations.AlterField(
            model_name='document',
            name='licenses',
            field=models.ManyToManyField(blank=True, to='ishtar_common.LicenseType', verbose_name='Rights of use / license'),
        ),
        migrations.AlterField(
            model_name='gdprlog',
            name='activity',
            field=models.CharField(choices=[('DC', 'Directory consultation'), ('DE', 'Directory export'), ('PV', "Viewing a person's notice"), ('PE', "Exporting a person's notice"), ('PC', 'Person creation'), ('PM', 'Person modification'), ('Pm', 'Person merge'), ('PD', 'Person deletion'), ('AC', 'Admin - Directory consultation'), ('AV', 'Admin - Person view'), ('AM', 'Admin - Person modification'), ('AD', 'Admin - Person deletion')], max_length=2, verbose_name='Activity'),
        ),
        migrations.CreateModel(
            name='BiographicalNote',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('search_vector', django.contrib.postgres.search.SearchVectorField(blank=True, help_text='Auto filled at save', null=True, verbose_name='Search vector')),
                ('timestamp_geo', models.IntegerField(blank=True, null=True, verbose_name='Timestamp geo')),
                ('timestamp_label', models.IntegerField(blank=True, null=True, verbose_name='Timestamp label')),
                ('data', django.contrib.postgres.fields.jsonb.JSONField(blank=True, default=dict)),
                ('last_modified', models.DateTimeField(blank=True, default=datetime.datetime.now)),
                ('created', models.DateTimeField(blank=True, default=datetime.datetime.now)),
                ('history_m2m', django.contrib.postgres.fields.jsonb.JSONField(blank=True, default=dict)),
                ('need_update', models.BooleanField(default=False, verbose_name='Need update')),
                ('locked', models.BooleanField(default=False, verbose_name='Item locked for edition')),
                ('denomination', models.TextField(verbose_name='Denomination')),
                ('last_name', models.TextField(blank=True, default='', verbose_name='Last name')),
                ('first_name', models.TextField(blank=True, default='', verbose_name='First name')),
                ('birth_year', models.PositiveIntegerField(blank=True, null=True, verbose_name='Year of birth')),
                ('death_year', models.PositiveIntegerField(blank=True, null=True, verbose_name='Year of death')),
                ('biography', models.TextField(blank=True, default='', verbose_name='Biography')),
                ('biography_format', models.CharField(blank=True, choices=[('NO', 'None'), ('MD', 'Markdown'), ('HT', 'HTML')], default='NO', max_length=2, verbose_name='Biography format')),
                ('history_creator', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL, verbose_name='Creator')),
                ('history_modifier', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL, verbose_name='Last editor')),
                ('imports', models.ManyToManyField(blank=True, related_name='imported_ishtar_common_biographicalnote', to='ishtar_common.Import')),
                ('imports_updated', models.ManyToManyField(blank=True, related_name='import_updated_ishtar_common_biographicalnote', to='ishtar_common.Import')),
                ('lock_user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL, verbose_name='Locked by')),
                ('organization', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='biographical_notes', to='ishtar_common.Organization', verbose_name='Organization')),
                ('person', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='biographical_notes', to='ishtar_common.Person', verbose_name='Person')),
            ],
            options={
                'verbose_name': 'Biographical note',
                'verbose_name_plural': 'Biographical notes',
            },
            bases=(ishtar_common.models_common.StatisticItem, ishtar_common.models_common.TemplateItem, models.Model, ishtar_common.models_common.CachedGen, ishtar_common.models_common.FixAssociated, ishtar_common.models.ValueGetter, ishtar_common.models_common.MainItem),
        ),
        migrations.AddField(
            model_name='document',
            name='shooting_angle',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='ishtar_common.ShootingAngle', verbose_name='Shooting angle'),
        ),
        migrations.AddField(
            model_name='historicaldocument',
            name='shooting_angle',
            field=models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='ishtar_common.ShootingAngle', verbose_name='Shooting angle'),
        ),
    ]
